/* Copyright (c) 2009 Nordic Semiconductor. All Rights Reserved.
 *
 * The information contained herein is confidential property of Nordic
 * Semiconductor ASA.Terms and conditions of usage are described in detail
 * in NORDIC SEMICONDUCTOR STANDARD SOFTWARE LICENSE AGREEMENT.
 *
 * Licensees are granted free, non-transferable use of the information. NO
 * WARRANTY of ANY KIND is provided. This heading must NOT be removed from
 * the file.
 *
 */

/** @file
* @brief SPI Master loopback example.
* @defgroup spi_master_example SPI master loopback usage example
* @{
* @ingroup nrf_examples_nrf6310
*
* @brief SPI master example.
*
* This example needs that the slave is configured to transmit the received bytes. That is the slave
* behaves as a loopback device for the master. The loopback can also be achieved without using a slave device at all by wiring MOSI and
* MISO pins of the spi master together. @ref TX_RX_MSG_LENGTH number of bytes are transmitted through the master and the received bytes are
* verified to be the same as transmitted. IF there is an error, gpio pin for relevant spi module is set high to show the error @sa ERROR_PIN_SPI0,
* @sa ERROR_PIN_SPI1. If there is error from both modules that is if both pins are set high, then this application loops for ever
*
*/

#include "spi_master2.h"
#include "nrf_delay.h"
#include "nrf_gpio.h"
#include "common.h"

#define SPI_PACKET_LENGTH 16

static uint8_t tx_data[SPI_PACKET_LENGTH];               /*!< SPI TX buffer */
static uint8_t rx_data[SPI_PACKET_LENGTH];               /*!< SPI RX buffer */

/**
 * main() function
 * @return 0. int return type required by ANSI/ISO standard. 
 */

int main(void)
{   
    SPIConfig_t my_spi = {.Config.Fields.BitOrder = SPI_BITORDER_MSB_LSB,
                          .Config.Fields.Mode     = SPI_MODE0,
                          .Frequency              = SPI_FREQ_8MBPS,
                          .Pin_SCK                = 16,
                          .Pin_MOSI               = 17,
                          .Pin_MISO               = 18,
                          .Pin_CSN                = 19};

                          // Initialize the SPI0 interface with the selected settings
    spi_master_init(SPI0, &my_spi);
                   
    while(1)
    {    
        // Full duplex SPI
        spi_master_tx_rx(SPI0, SPI_PACKET_LENGTH, tx_data, rx_data);
    
        // SPI write only
        spi_master_tx(SPI0, SPI_PACKET_LENGTH, tx_data);
        
        nrf_delay_us(500000);
    }
}
